@@ -5,13 +5,13 @@
 
 #include "solveassistant.h"
 
-#include <QAction>
 #include <QIcon>
 #include <QStyle>
 #include <QDialog>
+#include <QPushButton>
+
 #include <KActionCollection>
 #include <KConfigGroup>
-#include <QPushButton>
 #include "ui_solvedlg.h"
 #include "cantor_macros.h"
 #include "backend.h"
@@ -25,7 +25,7 @@ SolveAssistant::SolveAssistant(QObject* parent, QList<QVariant> args) : Assistan
 void SolveAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_solve_assistant.rc"));
-    QAction* solve=new QAction(i18n("Solve equations"), actionCollection());
+    auto* solve = new QAction(i18n("Solve equations"), actionCollection());
     solve->setIcon(QIcon::fromTheme(icon()));
     actionCollection()->addAction(QLatin1String("solve_assistant"), solve);
     connect(solve, &QAction::triggered, this, &SolveAssistant::requested);
@@ -33,30 +33,29 @@ void SolveAssistant::initActions()
 
 QStringList SolveAssistant::run(QWidget* parent)
 {
-    QPointer<QDialog> dlg=new QDialog(parent);
-    QWidget *widget=new QWidget(dlg);
+    QPointer<QDialog> dlg = new QDialog(parent);
+    auto* widget = new QWidget(dlg);
     Ui::SolveAssistantBase base;
     base.setupUi(widget);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    auto* mainLayout = new QVBoxLayout;
     dlg->setLayout(mainLayout);
     mainLayout->addWidget(widget);
 
     base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
     base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
-
-    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()) );
-    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()) );
+    connect(base.buttonBox, &QDialogButtonBox::accepted, dlg, &QDialog::accept);
+    connect(base.buttonBox, &QDialogButtonBox::rejected, dlg, &QDialog::reject);
 
     QStringList result;
     if( dlg->exec())
     {
-        QStringList equations=base.equations->toPlainText().split(QLatin1Char('\n'));
-        QStringList variables=base.variables->text().split(QLatin1String(", "));
-
-        Cantor::CASExtension* ext=
-            dynamic_cast<Cantor::CASExtension*>(backend()->extension(QLatin1String("CASExtension")));
-
-        result<<ext->solve(equations, variables);
+        auto* ext = dynamic_cast<Cantor::CASExtension*>(backend()->extension(QLatin1String("CASExtension")));
+        if (ext)
+        {
+            const auto& equations = base.equations->toPlainText().split(QLatin1Char('\n'));
+            const auto& variables = base.variables->text().split(QLatin1String(", "));
+            result<<ext->solve(equations, variables);
+        }
     }
 
     delete dlg;
