@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+*/
 
 #ifndef DEFAULTHIGHLIGHTER_H
 #define DEFAULTHIGHLIGHTER_H
@@ -171,7 +156,7 @@ class CANTOR_EXPORT DefaultHighlighter : public QSyntaxHighlighter
     void highlightRegExps(const QString& text);
 
     /**
-     * Returns a string  that contains a regular expression that matches for characters thar are allowed inside
+     * Returns a string that contains a regular expression that matches for characters that are allowed inside
      * words for this backend. For example, maxima or scilab allow % at the beginning of variable names
      */
     virtual QString nonSeparatingCharacters() const;
