@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2018 Yifei Wu <kqwyfg@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2018 Yifei Wu <kqwyfg@gmail.com>
+*/
 
 #ifndef MARKDOWNENTRY_H
 #define MARKDOWNENTRY_H
@@ -59,8 +44,6 @@ class MarkdownEntry : public WorksheetEntry
 
     QString plainText() const;
 
-    void interruptEvaluation() override;
-
     void layOutForWidth(qreal entry_zone_x, qreal w, bool force = false) override;
 
     WorksheetCursor search(const QString& pattern, unsigned flags,
@@ -91,6 +74,7 @@ class MarkdownEntry : public WorksheetEntry
     void handleMathRender(QSharedPointer<MathRenderResult> result);
     void insertImage();
     void clearAttachments();
+    void enterEditMode();
 
   protected:
     WorksheetTextItem* m_textItem;
